<?php $TRANSLATIONS = array(
"OpenID Changed" => "OpenID је измењен",
"Invalid request" => "Неисправан захтев",
"Language changed" => "Језик је измењен",
"Select an App" => "Изаберите програм",
"Ask a question" => "Поставите питање",
"Problems connecting to help database." => "Проблем у повезивању са базом помоћи",
"Go there manually." => "Отиђите тамо ручно.",
"Answer" => "Одговор",
"Unable to change your password" => "Не могу да изменим вашу лозинку",
"Current password" => "Тренутна лозинка",
"New password" => "Нова лозинка",
"show" => "прикажи",
"Change password" => "Измени лозинку",
"Email" => "Е-пошта",
"Your email address" => "Ваша адреса е-поште",
"Language" => "Језик",
"Help translate" => " Помозите у превођењу",
"use this address to connect to your ownCloud in your file manager" => "користите ову адресу да би се повезали на ownCloud путем менаџњера фајлова",
"Name" => "Име",
"Password" => "Лозинка",
"Groups" => "Групе",
"Create" => "Направи",
"Delete" => "Обриши"
);
